@@ -1,24 +1,30 @@
-#' Create SPARQL quries
+#' Create SPARQL queries
 #'
 #' Generates pre-defined or manual SPARQL queries to retrieve document ids from Cellar.
 #' List of available resource types: http://publications.europa.eu/resource/authority/resource-type .
-#' Note that not all resource types are compatible with the pre-defined query.
+#' Note that not all resource types are compatible with default parameter values.
 #'
 #' @importFrom magrittr %>%
 #'
 #' @param resource_type Type of resource to be retrieved via SPARQL query
 #' @param manual_type Define manually the type of resource to be retrieved
+#' @param directory Restrict the results to a given directory code
+#' @param sector Restrict the results to a given sector code
 #' @param include_corrigenda If `TRUE`, results include corrigenda
 #' @param include_celex If `TRUE`, results include CELEX identifier for each resource URI
 #' @param include_date If `TRUE`, results include document date
 #' @param include_date_force If `TRUE`, results include date of entry into force
 #' @param include_date_endvalid If `TRUE`, results include date of end of validity
 #' @param include_date_transpos If `TRUE`, results include date of transposition deadline for directives
+#' @param include_date_lodged If `TRUE`, results include date a court case was lodged with the court
 #' @param include_lbs If `TRUE`, results include legal bases of legislation
 #' @param include_force If `TRUE`, results include whether legislation is in force
 #' @param include_eurovoc If `TRUE`, results include EuroVoc descriptors of subject matter
 #' @param include_author If `TRUE`, results include document author(s)
 #' @param include_citations If `TRUE`, results include citations (CELEX-labelled)
+#' @param include_court_procedure If `TRUE`, results include type of court procedure and outcome
+#' @param include_directory If `TRUE`, results include the Eur-Lex directory code
+#' @param include_sector If `TRUE`, results include the Eur-Lex sector code
 #' @param order Order results by ids
 #' @param limit Limit the number of results, for testing purposes mainly
 #' @return
@@ -30,18 +36,27 @@
 #' elx_make_query(resource_type = "caselaw")
 #' elx_make_query(resource_type = "manual", manual_type = "SWD")
 
-elx_make_query <- function(resource_type = c("directive","regulation","decision","recommendation","intagr","caselaw","manual","proposal","national_impl"),
-                           manual_type = "", include_corrigenda = FALSE, include_celex = TRUE, include_lbs = FALSE,
+elx_make_query <- function(resource_type = c("directive","regulation","decision","recommendation","intagr","caselaw","manual","proposal","national_impl","any"),
+                           manual_type = "", directory = NULL, sector = NULL,
+                           include_corrigenda = FALSE, include_celex = TRUE, include_lbs = FALSE,
                            include_date = FALSE, include_date_force = FALSE, include_date_endvalid = FALSE,
-                           include_date_transpos = FALSE, include_force = FALSE, include_eurovoc = FALSE,
-                           include_author = FALSE, include_citations = FALSE, order = FALSE, limit = NULL){
+                           include_date_transpos = FALSE, include_date_lodged = FALSE,
+                           include_force = FALSE, include_eurovoc = FALSE, include_author = FALSE,
+                           include_citations = FALSE, include_court_procedure = FALSE,
+                           include_directory = FALSE, include_sector = FALSE,
+                           order = FALSE, limit = NULL){
 
-  if (!resource_type %in% c("directive","regulation","decision","recommendation","intagr","caselaw","manual","proposal","national_impl")) stop("'resource_type' must be defined")
+  if (missing(resource_type)) stop("'resource_type' must be defined")
+  if (!resource_type %in% c("any","directive","regulation","decision","recommendation","intagr","caselaw","manual","proposal","national_impl")) stop("'resource_type' must be defined")
 
   if (resource_type == "manual" & nchar(manual_type) < 2){
     stop("Please specify resource type manually (e.g. 'DIR', 'REG', 'JUDG').", call. = TRUE)
   }
 
+  if (!resource_type %in% c("caselaw","manual") & include_court_procedure == TRUE){
+    stop("Resource and variable requested are incompatible.", call. = TRUE)
+  }
+
   if (include_date_transpos == TRUE & resource_type!="directive"){
     stop("Transposition date currently only available for directives.", call. = TRUE)
   }
@@ -85,6 +100,12 @@ elx_make_query <- function(resource_type = c("directive","regulation","decision"
 
   }
 
+  if (include_date_lodged == TRUE){
+
+    query <- paste(query, "str(?datelodged)", sep = " ")
+
+  }
+
   if (include_lbs == TRUE){
 
     if (resource_type %in% c("caselaw")){
@@ -111,6 +132,12 @@ elx_make_query <- function(resource_type = c("directive","regulation","decision"
 
   }
 
+  if (include_court_procedure == TRUE){
+
+    query <- paste(query, "?courtprocedure", sep = " ")
+
+  }
+
   if (include_author == TRUE){
 
     query <- paste(query, "?author", sep = " ")
@@ -123,7 +150,54 @@ elx_make_query <- function(resource_type = c("directive","regulation","decision"
 
   }
 
-  query <- paste(query, "where{ ?work cdm:work_has_resource-type ?type.", sep = " ")
+  if (include_directory == TRUE){
+
+    query <- paste(query, "?directory", sep = " ")
+
+  }
+
+  if (include_sector == TRUE){
+
+    query <- paste(query, "?sector", sep = " ")
+
+  }
+
+  if (resource_type == "any"){
+    query <- paste(query, "where{", sep = " ")
+  }
+
+  if (resource_type != "any"){
+    query <- paste(query, "where{ ?work cdm:work_has_resource-type ?type.", sep = " ")
+  }
+
+  if (!missing(directory)){
+    if (!is.character(directory)) stop("Directory code must be of character type", call. = TRUE)
+
+    query <- paste(query, "
+    VALUES (?value)
+    { (<http://publications.europa.eu/resource/authority/fd_555/",directory,">)
+      (<http://publications.europa.eu/resource/authority/dir-eu-legal-act/",directory,">)
+    }
+    {?work cdm:resource_legal_is_about_concept_directory-code ?value.
+    }
+    UNION
+    {?work cdm:resource_legal_is_about_concept_directory-code ?directory.
+      ?value skos:narrower+ ?directory.
+    }
+    ", sep = "")
+
+  }
+
+  if (!missing(sector)){
+    if (!sector %in% 0:9) stop("Sector code must be an integer between 0 and 9", call. = TRUE)
+
+    query <- paste(query, "
+    ?work cdm:resource_legal_id_sector ?sector.
+    FILTER(str(?sector)='", sector, "')
+    ",
+                   sep = "")
+
+  }
 
   if (resource_type == "directive"){
     query <- paste(query, "FILTER(?type=<http://publications.europa.eu/resource/authority/resource-type/DIR>||
@@ -158,6 +232,9 @@ elx_make_query <- function(resource_type = c("directive","regulation","decision"
   ?type=<http://publications.europa.eu/resource/authority/resource-type/ARRANG>||
   ?type=<http://publications.europa.eu/resource/authority/resource-type/CONVENTION>||
   ?type=<http://publications.europa.eu/resource/authority/resource-type/AGREE_AMEND>||
+  ?type=<http://publications.europa.eu/resource/authority/resource-type/RECO_ADOPT_INTERNATION>||
+  ?type=<http://publications.europa.eu/resource/authority/resource-type/REG_ADOPT_INTERNATION>||
+  ?type=<http://publications.europa.eu/resource/authority/resource-type/DEC_ADOPT_INTERNATION>||
   ?type=<http://publications.europa.eu/resource/authority/resource-type/MEMORANDUM_UNDERST>)", sep = " ")
   }
 
@@ -277,6 +354,12 @@ elx_make_query <- function(resource_type = c("directive","regulation","decision"
 
   }
 
+  if (include_date_lodged == TRUE){
+
+    query <- paste(query, "OPTIONAL{?work cdm:resource_legal_date_request_opinion ?datelodged.}")
+
+  }
+
   if (include_lbs == TRUE & resource_type!="caselaw"){
 
     query <- paste(query, "OPTIONAL{?work cdm:resource_legal_based_on_resource_legal ?lbs.
@@ -314,6 +397,25 @@ elx_make_query <- function(resource_type = c("directive","regulation","decision"
 
   }
 
+  if (include_court_procedure == TRUE){
+
+    query <- paste(query, "OPTIONAL{?work cdm:case-law_has_type_procedure_concept_type_procedure ?proc.
+           ?proc skos:prefLabel ?courtprocedure. FILTER(lang(?courtprocedure)='en')}.")
+
+  }
+
+  if (include_directory == TRUE){
+
+    query <- paste(query, "OPTIONAL{?work cdm:resource_legal_is_about_concept_directory-code ?directory.}")
+
+  }
+
+  if (include_sector == TRUE){
+
+    query <- paste(query, "OPTIONAL{?work cdm:resource_legal_id_sector ?sector.}")
+
+  }
+
   if (order == TRUE){
     query <- paste(query, "} order by str(?date)")
   } else {query <- paste(query, "}")}
